bread.templatetags package
==========================

.. automodule:: bread.templatetags
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

bread.templatetags.bread\_tags module
-------------------------------------

.. automodule:: bread.templatetags.bread_tags
   :members:
   :undoc-members:
   :show-inheritance:
